# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class RedemptionCodeMetadata(object):

    """Implementation of the 'RedemptionCodeMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        content_title (string): TODO: type description here.
        content_type (string): TODO: type description here.
        created_at (string): TODO: type description here.
        redeemed_at (string): TODO: type description here.
        site_id (string): TODO: type description here.
        updated_at (string): TODO: type description here.
        nice_code (string): QJB5-JX5V-6JQ5
        available (string): TODO: type description here.
        redeemed (string): TODO: type description here.
        expired (string): TODO: type description here.
        code (string): TODO: type description here.
        expiration_date (string): TODO: type description here.
        video_id (string): TODO: type description here.
        pass_plan_id (string): TODO: type description here.
        plan_id (string): TODO: type description here.
        playlist_id (string): TODO: type description here.
        transaction_id (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "content_title": 'content_title',
        "content_type": 'content_type',
        "created_at": 'created_at',
        "redeemed_at": 'redeemed_at',
        "site_id": 'site_id',
        "updated_at": 'updated_at',
        "nice_code": 'nice_code',
        "available": 'available',
        "redeemed": 'redeemed',
        "expired": 'expired',
        "code": 'code',
        "expiration_date": 'expiration_date',
        "video_id": 'video_id',
        "pass_plan_id": 'pass_plan_id',
        "plan_id": 'plan_id',
        "playlist_id": 'playlist_id',
        "transaction_id": 'transaction_id'
    }

    def __init__(self,
                 id=None,
                 content_title=None,
                 content_type=None,
                 created_at=None,
                 redeemed_at=None,
                 site_id=None,
                 updated_at=None,
                 nice_code=None,
                 available=None,
                 redeemed=None,
                 expired=None,
                 code=None,
                 expiration_date=None,
                 video_id=None,
                 pass_plan_id=None,
                 plan_id=None,
                 playlist_id=None,
                 transaction_id=None):
        """Constructor for the RedemptionCodeMetadata class"""

        # Initialize members of the class
        self.id = id
        self.content_title = content_title
        self.content_type = content_type
        self.created_at = created_at
        self.redeemed_at = redeemed_at
        self.site_id = site_id
        self.updated_at = updated_at
        self.nice_code = nice_code
        self.available = available
        self.redeemed = redeemed
        self.expired = expired
        self.code = code
        self.expiration_date = expiration_date
        self.video_id = video_id
        self.pass_plan_id = pass_plan_id
        self.plan_id = plan_id
        self.playlist_id = playlist_id
        self.transaction_id = transaction_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        content_title = dictionary.get('content_title')
        content_type = dictionary.get('content_type')
        created_at = dictionary.get('created_at')
        redeemed_at = dictionary.get('redeemed_at')
        site_id = dictionary.get('site_id')
        updated_at = dictionary.get('updated_at')
        nice_code = dictionary.get('nice_code')
        available = dictionary.get('available')
        redeemed = dictionary.get('redeemed')
        expired = dictionary.get('expired')
        code = dictionary.get('code')
        expiration_date = dictionary.get('expiration_date')
        video_id = dictionary.get('video_id')
        pass_plan_id = dictionary.get('pass_plan_id')
        plan_id = dictionary.get('plan_id')
        playlist_id = dictionary.get('playlist_id')
        transaction_id = dictionary.get('transaction_id')

        # Return an object of this model
        return cls(id,
                   content_title,
                   content_type,
                   created_at,
                   redeemed_at,
                   site_id,
                   updated_at,
                   nice_code,
                   available,
                   redeemed,
                   expired,
                   code,
                   expiration_date,
                   video_id,
                   pass_plan_id,
                   plan_id,
                   playlist_id,
                   transaction_id)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Original(object):

    """Implementation of the 'original' model.

    TODO: type model description here.

    Attributes:
        url (string): TODO: type description here.
        size (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "url": 'url',
        "size": 'size'
    }

    def __init__(self,
                 url=None,
                 size=None):
        """Constructor for the Original class"""

        # Initialize members of the class
        self.url = url
        self.size = size

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        url = dictionary.get('url')
        size = dictionary.get('size')

        # Return an object of this model
        return cls(url,
                   size)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SubscriptionMetadata(object):

    """Implementation of the 'SubscriptionMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): ID of the record
        amount (string): TODO: type description here.
        created_at (string): TODO: type description here.
        currency (string): will match the Plan's currency
        current_period_end_at (string): TODO: type description here.
        current_period_start_at (string): TODO: type description here.
        discount_amount (float): TODO: type description here.
        discount_duration (string): TODO: type description here.
        discount_duration_months (float): TODO: type description here.
        discount_percent (float): TODO: type description here.
        mrr (float): TODO: type description here.
        plan_id (string): TODO: type description here.
        site_id (string): TODO: type description here.
        start_at (string): TODO: type description here.
        trial_period_days (float): TODO: type description here.
        updated_at (string): TODO: type description here.
        plan_name (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "amount": 'amount',
        "created_at": 'created_at',
        "currency": 'currency',
        "current_period_end_at": 'current_period_end_at',
        "current_period_start_at": 'current_period_start_at',
        "discount_amount": 'discount_amount',
        "discount_duration": 'discount_duration',
        "discount_duration_months": 'discount_duration_months',
        "discount_percent": 'discount_percent',
        "mrr": 'mrr',
        "plan_id": 'plan_id',
        "site_id": 'site_id',
        "start_at": 'start_at',
        "trial_period_days": 'trial_period_days',
        "updated_at": 'updated_at',
        "plan_name": 'plan_name'
    }

    def __init__(self,
                 id=None,
                 amount=None,
                 created_at=None,
                 currency=None,
                 current_period_end_at=None,
                 current_period_start_at=None,
                 discount_amount=None,
                 discount_duration=None,
                 discount_duration_months=None,
                 discount_percent=None,
                 mrr=None,
                 plan_id=None,
                 site_id=None,
                 start_at=None,
                 trial_period_days=None,
                 updated_at=None,
                 plan_name=None):
        """Constructor for the SubscriptionMetadata class"""

        # Initialize members of the class
        self.id = id
        self.amount = amount
        self.created_at = created_at
        self.currency = currency
        self.current_period_end_at = current_period_end_at
        self.current_period_start_at = current_period_start_at
        self.discount_amount = discount_amount
        self.discount_duration = discount_duration
        self.discount_duration_months = discount_duration_months
        self.discount_percent = discount_percent
        self.mrr = mrr
        self.plan_id = plan_id
        self.site_id = site_id
        self.start_at = start_at
        self.trial_period_days = trial_period_days
        self.updated_at = updated_at
        self.plan_name = plan_name

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        amount = dictionary.get('amount')
        created_at = dictionary.get('created_at')
        currency = dictionary.get('currency')
        current_period_end_at = dictionary.get('current_period_end_at')
        current_period_start_at = dictionary.get('current_period_start_at')
        discount_amount = dictionary.get('discount_amount')
        discount_duration = dictionary.get('discount_duration')
        discount_duration_months = dictionary.get('discount_duration_months')
        discount_percent = dictionary.get('discount_percent')
        mrr = dictionary.get('mrr')
        plan_id = dictionary.get('plan_id')
        site_id = dictionary.get('site_id')
        start_at = dictionary.get('start_at')
        trial_period_days = dictionary.get('trial_period_days')
        updated_at = dictionary.get('updated_at')
        plan_name = dictionary.get('plan_name')

        # Return an object of this model
        return cls(id,
                   amount,
                   created_at,
                   currency,
                   current_period_end_at,
                   current_period_start_at,
                   discount_amount,
                   discount_duration,
                   discount_duration_months,
                   discount_percent,
                   mrr,
                   plan_id,
                   site_id,
                   start_at,
                   trial_period_days,
                   updated_at,
                   plan_name)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.content_rule_metadata import ContentRuleMetadata


class VideoContentRulesController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(VideoContentRulesController, self).__init__(config, call_back)

    def videos_content_rules_by_video_id_get(self,
                                             video_id):
        """Does a GET request to /videos/{video_id}/content_rules.

        List Content Rules for a Video

        Args:
            video_id (string): video ID

        Returns:
            list of ContentRuleMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{video_id}/content_rules'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'video_id': {'value': video_id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ContentRuleMetadata.from_dictionary)

        return decoded

    def videos_content_rules_by_video_id_post(self,
                                              body,
                                              video_id):
        """Does a POST request to /videos/{video_id}/content_rules.

        Create Video Content Rule

        Args:
            body (ContentRuleRequest): TODO: type description here.
            video_id (string): TODO: type description here.

        Returns:
            ContentRuleMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{video_id}/content_rules'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'video_id': {'value': video_id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ContentRuleMetadata.from_dictionary)

        return decoded

    def videos_content_rules_by_video_id_and_id_get(self,
                                                    video_id,
                                                    id):
        """Does a GET request to /videos/{video_id}/content_rules/{id}.

        View Video Content Rule

        Args:
            video_id (string): video ID
            id (string): content rule ID

        Returns:
            ContentRuleMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{video_id}/content_rules/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'video_id': {'value': video_id, 'encode': True},
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ContentRuleMetadata.from_dictionary)

        return decoded

    def videos_content_rules_by_video_id_and_id_put(self,
                                                    video_id,
                                                    id,
                                                    body):
        """Does a PUT request to /videos/{video_id}/content_rules/{id}.

        Update Video Content Rule

        Args:
            video_id (string): video ID
            id (string): content rule ID
            body (ContentRuleRequest): TODO: type description here.

        Returns:
            ContentRuleMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{video_id}/content_rules/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'video_id': {'value': video_id, 'encode': True},
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, ContentRuleMetadata.from_dictionary)

        return decoded

    def videos_content_rules_by_video_id_and_id_delete(self,
                                                       video_id,
                                                       id):
        """Does a DELETE request to /videos/{video_id}/content_rules/{id}.

        Delete Video Content Rule

        Args:
            video_id (string): video ID
            id (string): content rule ID

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{video_id}/content_rules/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'video_id': {'value': video_id, 'encode': True},
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.delete(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from zypev1.models.picture_metadata import PictureMetadata


class ZobjectMetadata(object):

    """Implementation of the 'ZobjectMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        created_at (string): TODO: type description here.
        site_id (string): TODO: type description here.
        updated_at (string): TODO: type description here.
        video_ids (list of string): TODO: type description here.
        zobject_type_id (string): TODO: type description here.
        pictures (list of PictureMetadata): TODO: type description here.
        title (string): TODO: type description here.
        description (string): TODO: type description here.
        friendly_title (string): mckellen
        keywords (list of string): TODO: type description here.
        active (string): TODO: type description here.
        zobject_type_title (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "created_at": 'created_at',
        "site_id": 'site_id',
        "updated_at": 'updated_at',
        "video_ids": 'video_ids',
        "zobject_type_id": 'zobject_type_id',
        "pictures": 'pictures',
        "title": 'title',
        "description": 'description',
        "friendly_title": 'friendly_title',
        "keywords": 'keywords',
        "active": 'active',
        "zobject_type_title": 'zobject_type_title'
    }

    def __init__(self,
                 id=None,
                 created_at=None,
                 site_id=None,
                 updated_at=None,
                 video_ids=None,
                 zobject_type_id=None,
                 pictures=None,
                 title=None,
                 description=None,
                 friendly_title=None,
                 keywords=None,
                 active=None,
                 zobject_type_title=None):
        """Constructor for the ZobjectMetadata class"""

        # Initialize members of the class
        self.id = id
        self.created_at = created_at
        self.site_id = site_id
        self.updated_at = updated_at
        self.video_ids = video_ids
        self.zobject_type_id = zobject_type_id
        self.pictures = pictures
        self.title = title
        self.description = description
        self.friendly_title = friendly_title
        self.keywords = keywords
        self.active = active
        self.zobject_type_title = zobject_type_title

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        created_at = dictionary.get('created_at')
        site_id = dictionary.get('site_id')
        updated_at = dictionary.get('updated_at')
        video_ids = dictionary.get('video_ids')
        zobject_type_id = dictionary.get('zobject_type_id')
        pictures = None
        if dictionary.get('pictures') is not None:
            pictures = [PictureMetadata.from_dictionary(x) for x in dictionary.get('pictures')]
        title = dictionary.get('title')
        description = dictionary.get('description')
        friendly_title = dictionary.get('friendly_title')
        keywords = dictionary.get('keywords')
        active = dictionary.get('active')
        zobject_type_title = dictionary.get('zobject_type_title')

        # Return an object of this model
        return cls(id,
                   created_at,
                   site_id,
                   updated_at,
                   video_ids,
                   zobject_type_id,
                   pictures,
                   title,
                   description,
                   friendly_title,
                   keywords,
                   active,
                   zobject_type_title)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SubscriptionRequest(object):

    """Implementation of the 'SubscriptionRequest' model.

    TODO: type model description here.

    Attributes:
        consumer_id (string): TODO: type description here.
        plan_id (string): TODO: type description here.
        stripe_card_token (string): TODO: type description here.
        stripe_id_sub_cl_hnbh_4_h_jpoi_abz (string): TODO: type description
            here.
        braintree_payment_nonce (string): TODO: type description here.
        braintree_id (string): TODO: type description here.
        status (string): TODO: type description here.
        cancelled_at (string): TODO: type description here.
        cancel_at_period_end (bool): TODO: type description here.
        coupon_code (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "consumer_id": 'consumer_id',
        "plan_id": 'plan_id',
        "stripe_card_token": 'stripe_card_token',
        "stripe_id_sub_cl_hnbh_4_h_jpoi_abz": 'stripe_id: sub_ClHNBH4hJPOIAbz',
        "braintree_payment_nonce": 'braintree_payment_nonce',
        "braintree_id": 'braintree_id',
        "status": 'status',
        "cancelled_at": 'cancelled_at',
        "cancel_at_period_end": 'cancel_at_period_end',
        "coupon_code": 'coupon_code'
    }

    def __init__(self,
                 consumer_id=None,
                 plan_id=None,
                 stripe_card_token=None,
                 stripe_id_sub_cl_hnbh_4_h_jpoi_abz=None,
                 braintree_payment_nonce=None,
                 braintree_id=None,
                 status=None,
                 cancelled_at=None,
                 cancel_at_period_end=None,
                 coupon_code=None):
        """Constructor for the SubscriptionRequest class"""

        # Initialize members of the class
        self.consumer_id = consumer_id
        self.plan_id = plan_id
        self.stripe_card_token = stripe_card_token
        self.stripe_id_sub_cl_hnbh_4_h_jpoi_abz = stripe_id_sub_cl_hnbh_4_h_jpoi_abz
        self.braintree_payment_nonce = braintree_payment_nonce
        self.braintree_id = braintree_id
        self.status = status
        self.cancelled_at = cancelled_at
        self.cancel_at_period_end = cancel_at_period_end
        self.coupon_code = coupon_code

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        consumer_id = dictionary.get('consumer_id')
        plan_id = dictionary.get('plan_id')
        stripe_card_token = dictionary.get('stripe_card_token')
        stripe_id_sub_cl_hnbh_4_h_jpoi_abz = dictionary.get('stripe_id: sub_ClHNBH4hJPOIAbz')
        braintree_payment_nonce = dictionary.get('braintree_payment_nonce')
        braintree_id = dictionary.get('braintree_id')
        status = dictionary.get('status')
        cancelled_at = dictionary.get('cancelled_at')
        cancel_at_period_end = dictionary.get('cancel_at_period_end')
        coupon_code = dictionary.get('coupon_code')

        # Return an object of this model
        return cls(consumer_id,
                   plan_id,
                   stripe_card_token,
                   stripe_id_sub_cl_hnbh_4_h_jpoi_abz,
                   braintree_payment_nonce,
                   braintree_id,
                   status,
                   cancelled_at,
                   cancel_at_period_end,
                   coupon_code)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class App(object):

    """Implementation of the 'App' model.

    TODO: type model description here.

    Attributes:
        id (string): ID of the record
        active (bool): true
        app_type_id (string): ID of the AppType this app belongs to (AppleTV,
            Android, iOS, etc)
        device_ids (string): Devices the app can play on
        site_id (string): Site the app belongs to
        title (string): Descriptive title of the app
        version (string): TODO: type description here.
        store_icon_url (string): icon.com

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "active": 'active',
        "app_type_id": 'app_type_id',
        "device_ids": 'device_ids',
        "site_id": 'site_id',
        "title": 'title',
        "version": 'version',
        "store_icon_url": 'store_icon_url'
    }

    def __init__(self,
                 id=None,
                 active=None,
                 app_type_id=None,
                 device_ids=None,
                 site_id=None,
                 title=None,
                 version=None,
                 store_icon_url=None):
        """Constructor for the App class"""

        # Initialize members of the class
        self.id = id
        self.active = active
        self.app_type_id = app_type_id
        self.device_ids = device_ids
        self.site_id = site_id
        self.title = title
        self.version = version
        self.store_icon_url = store_icon_url

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        active = dictionary.get('active')
        app_type_id = dictionary.get('app_type_id')
        device_ids = dictionary.get('device_ids')
        site_id = dictionary.get('site_id')
        title = dictionary.get('title')
        version = dictionary.get('version')
        store_icon_url = dictionary.get('store_icon_url')

        # Return an object of this model
        return cls(id,
                   active,
                   app_type_id,
                   device_ids,
                   site_id,
                   title,
                   version,
                   store_icon_url)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.video_metadata import VideoMetadata


class VideosController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(VideosController, self).__init__(config, call_back)

    def videos_get(self,
                   active=None,
                   category=None,
                   created_at=None,
                   friendly_title=None,
                   id=None,
                   hulu_id=None,
                   vimeo_id=None,
                   youtube_id=None,
                   zobject_id=None,
                   mature_content=None,
                   order=None,
                   on_air=None,
                   page=None,
                   per_page=None,
                   published_at=None,
                   q=None,
                   sort=None,
                   source_id=None,
                   mtype=None,
                   dpt=None,
                   crunchyroll_id=None):
        """Does a GET request to /videos.

        List Videos

        Args:
            active (bool, optional): Filter by active, inactive, or all
                records
            category (string, optional): Filter by category value + Examples  
                + `category[genre][]=drama`     + use
                `category![genre][]=drama` to exclude by category value
            created_at (date, optional): Filter by created at date using times
                in ISO8601 format + Examples     + `2017-01-01T00:00:00-00:00`
                + `1483228800`
            friendly_title (string, optional): Filter by friendly title
            id (string, optional): Filter by id + Examples     +
                `id=3049df039402ld3029f930`     + use
                `id!=3049df039402ld3029f930` to exclude by id
            hulu_id (string, optional): Filter by Hulu ID
            vimeo_id (string, optional): Filter by Vimeo ID
            youtube_id (string, optional): Filter by YouTube ID
            zobject_id (string, optional): Filter by Zobject ID
            mature_content (bool, optional): Filter records flagged as mature
            order (string, optional): Filter by ascending or descending order
                + Examples     + `asc`     + `desc`
            on_air (bool, optional): Filter records that are either on or off
                air
            page (float, optional): Number of pages to return
            per_page (float, optional): Number of records to return per page
            published_at (date, optional): Filter records by published date
                using times in ISO8601 format + Examples:     +
                `2017-01-01T00:00:00-00:00`     + `1483228800`
            q (string, optional): Filter by keyword
            sort (string, optional): Sort on the specified field
            source_id (string, optional): Filter by source identifier
            mtype (string, optional): Filter by type + Examples:     + `zype` 
                + `hulu`     + `youtube`     + `crunchyroll`
            dpt (string, optional): TODO: type description here.
            crunchyroll_id (string, optional): TODO: type description here.

        Returns:
            list of VideoMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'active': active,
            'category': category,
            'created_at': created_at,
            'friendly_title': friendly_title,
            'id': id,
            'hulu_id': hulu_id,
            'vimeo_id': vimeo_id,
            'youtube_id': youtube_id,
            'zobject_id': zobject_id,
            'mature_content': mature_content,
            'order': order,
            'on_air': on_air,
            'page': page,
            'per_page': per_page,
            'published_at': published_at,
            'q': q,
            'sort': sort,
            'source_id': source_id,
            'type': mtype,
            'dpt': dpt,
            'crunchyroll_id': crunchyroll_id
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoMetadata.from_dictionary)

        return decoded

    def videos_post(self,
                    body,
                    active=None,
                    category=None,
                    created_at=None,
                    dpt=None,
                    crunchyroll_id=None,
                    friendly_title=None,
                    id=None,
                    hulu_id=None,
                    vimeo_id=None,
                    youtube_id=None,
                    zobject_id=None,
                    mature_content=None,
                    order=None,
                    on_air=None,
                    page=None,
                    per_page=None,
                    published_at=None,
                    q=None,
                    sort=None,
                    source_id=None,
                    mtype=None):
        """Does a POST request to /videos.

        Create a New Video

        Args:
            body (VideoRequest): TODO: type description here.
            active (string, optional): TODO: type description here.
            category (string, optional): TODO: type description here.
            created_at (string, optional): TODO: type description here.
            dpt (string, optional): TODO: type description here.
            crunchyroll_id (string, optional): TODO: type description here.
            friendly_title (string, optional): TODO: type description here.
            id (string, optional): TODO: type description here.
            hulu_id (string, optional): TODO: type description here.
            vimeo_id (string, optional): TODO: type description here.
            youtube_id (string, optional): TODO: type description here.
            zobject_id (string, optional): TODO: type description here.
            mature_content (string, optional): TODO: type description here.
            order (string, optional): TODO: type description here.
            on_air (string, optional): TODO: type description here.
            page (string, optional): TODO: type description here.
            per_page (string, optional): TODO: type description here.
            published_at (string, optional): TODO: type description here.
            q (string, optional): TODO: type description here.
            sort (string, optional): TODO: type description here.
            source_id (string, optional): TODO: type description here.
            mtype (string, optional): TODO: type description here.

        Returns:
            VideoMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'active': active,
            'category': category,
            'created_at': created_at,
            'dpt': dpt,
            'crunchyroll_id': crunchyroll_id,
            'friendly_title': friendly_title,
            'id': id,
            'hulu_id': hulu_id,
            'vimeo_id': vimeo_id,
            'youtube_id': youtube_id,
            'zobject_id': zobject_id,
            'mature_content': mature_content,
            'order': order,
            'on_air': on_air,
            'page': page,
            'per_page': per_page,
            'published_at': published_at,
            'q': q,
            'sort': sort,
            'source_id': source_id,
            'type': mtype
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoMetadata.from_dictionary)

        return decoded

    def videos_by_id_get(self,
                         id):
        """Does a GET request to /videos/{id}.

        View Video

        Args:
            id (string): ID of video

        Returns:
            VideoMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoMetadata.from_dictionary)

        return decoded

    def videos_by_id_put(self,
                         id,
                         body):
        """Does a PUT request to /videos/{id}.

        Update Video

        Args:
            id (string): ID of video
            body (VideoRequest): TODO: type description here.

        Returns:
            VideoMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoMetadata.from_dictionary)

        return decoded

    def videos_add_zobjects_by_id_put(self,
                                      id,
                                      body):
        """Does a PUT request to /videos/{id}/add_zobjects.

        Add Zobject(s) to Video

        Args:
            id (string): ID of video
            body (AddZobjectSToVideoRequest): TODO: type description here.

        Returns:
            VideoMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{id}/add_zobjects'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoMetadata.from_dictionary)

        return decoded

    def videos_remove_zobjects_by_id_put(self,
                                         id,
                                         body):
        """Does a PUT request to /videos/{id}/remove_zobjects.

        Remove Zobject(s) from Video

        Args:
            id (string): ID of video
            body (object): TODO: type description here.

        Returns:
            VideoMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{id}/remove_zobjects'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoMetadata.from_dictionary)

        return decoded

    def videos_download_by_id_get(self,
                                  id):
        """Does a GET request to /videos/{id}/download.

        Download original source file

        Args:
            id (string): ID of video

        Returns:
            string: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{id}/download'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = _response.text

        return decoded



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.subscription_metadata import SubscriptionMetadata


class SubscriptionsController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(SubscriptionsController, self).__init__(config, call_back)

    def subscriptions_get(self,
                          id=None,
                          created_at=None,
                          plan_id=None,
                          braintree_id=None,
                          stripe_id=None,
                          consumer_id=None,
                          q=None,
                          order=None,
                          sort=None,
                          page=None,
                          per_page=None):
        """Does a GET request to /subscriptions.

        List Subscriptions

        Args:
            id (string, optional): Filter by ID + Examples     +
                `id=5992f328ce593000ef000008`     + use
                `id!=5992f328ce593000ef000008` to exclude by id
            created_at (date, optional): Filter by created at date using times
                in ISO8601 format Note: Range filters can be applied by adding
                a suffix: ‘.gt’, ‘.gte’, ‘.lt’, ‘lte’ (Example:
                expires_at.gte) + Examples     + `2017-01-01T00:00:00-00:00` -
                in ISO8601 format     + `1483228800` - Unix timestamps
            plan_id (string, optional): ID of Plan
            braintree_id (string, optional): Filter by the consumer's
                Braintree ID
            stripe_id (string, optional): Filter by the consumer's Stripe ID
            consumer_id (string, optional): ID of consumer
            q (string, optional): Filter by keyword
            order (string, optional): Filter by ascending or descending order
                + Examples     + asc     + desc
            sort (string, optional): Sort on the specified field
            page (float, optional): Number of pages to return
            per_page (float, optional): Number of records to return per page

        Returns:
            SubscriptionMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/subscriptions'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'id': id,
            'created_at': created_at,
            'plan_id': plan_id,
            'braintree_id': braintree_id,
            'stripe_id': stripe_id,
            'consumer_id': consumer_id,
            'q': q,
            'order': order,
            'sort': sort,
            'page': page,
            'per_page': per_page
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, SubscriptionMetadata.from_dictionary)

        return decoded

    def subscriptions_post(self,
                           body,
                           created_at=None,
                           id=None,
                           plan_id=None,
                           braintree_id=None,
                           stripe_id=None,
                           consumer_id=None,
                           order=None,
                           sort=None,
                           page=None,
                           per_page=None,
                           q=None):
        """Does a POST request to /subscriptions.

        Create Subscriptions

        Args:
            body (SubscriptionRequest): TODO: type description here.
            created_at (string, optional): TODO: type description here.
            id (string, optional): TODO: type description here.
            plan_id (string, optional): TODO: type description here.
            braintree_id (string, optional): TODO: type description here.
            stripe_id (string, optional): TODO: type description here.
            consumer_id (string, optional): TODO: type description here.
            order (string, optional): TODO: type description here.
            sort (string, optional): TODO: type description here.
            page (string, optional): TODO: type description here.
            per_page (string, optional): TODO: type description here.
            q (string, optional): TODO: type description here.

        Returns:
            SubscriptionMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/subscriptions'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'created_at': created_at,
            'id': id,
            'plan_id': plan_id,
            'braintree_id': braintree_id,
            'stripe_id': stripe_id,
            'consumer_id': consumer_id,
            'order': order,
            'sort': sort,
            'page': page,
            'per_page': per_page,
            'q': q
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, SubscriptionMetadata.from_dictionary)

        return decoded

    def subscriptions_by_id_get(self,
                                id):
        """Does a GET request to /subscriptions/{id}.

        View Subscription

        Args:
            id (string): ID of the subscription

        Returns:
            SubscriptionMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/subscriptions/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, SubscriptionMetadata.from_dictionary)

        return decoded

    def subscriptions_by_id_put(self,
                                id,
                                body):
        """Does a PUT request to /subscriptions/{id}.

        Update Subscription

        Args:
            id (string): ID of the subscription
            body (SubscriptionRequest): TODO: type description here.

        Returns:
            SubscriptionMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/subscriptions/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, SubscriptionMetadata.from_dictionary)

        return decoded

    def subscriptions_by_id_delete(self,
                                   id):
        """Does a DELETE request to /subscriptions/{id}.

        Delete Subscription

        Args:
            id (string): ID of the subscription

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/subscriptions/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.delete(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.device_category import DeviceCategory


class DeviceCategoriesController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(DeviceCategoriesController, self).__init__(config, call_back)

    def device_categories_get(self,
                              title=None,
                              id=None,
                              created_at=None,
                              q=None,
                              order=None,
                              sort=None,
                              page=None,
                              per_page=None):
        """Does a GET request to /device_categories.

        List Devices Categories

        Args:
            title (string, optional): Filter by title
            id (string, optional): Filter by id + Examples     +
                `id=593030d74d740d0053000012`     + use
                `id!=593030d74d740d0053000012` to exclude by id
            created_at (string, optional): Filter by when the category was
                created
            q (string, optional): Filter by keyword
            order (string, optional): Filter by ascending or descending order
                + Examples     + `asc`     + `desc`
            sort (string, optional): Sort on the specified field
            page (float, optional): Number of pages to return
            per_page (float, optional): Number of records to return per page

        Returns:
            list of DeviceCategory: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/device_categories'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'title': title,
            'id': id,
            'created_at': created_at,
            'q': q,
            'order': order,
            'sort': sort,
            'page': page,
            'per_page': per_page
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, DeviceCategory.from_dictionary)

        return decoded

    def device_categories_by_id_get(self,
                                    id):
        """Does a GET request to /device_categories/{id}.

        View Device Category

        Args:
            id (string): ID of device category

        Returns:
            DeviceCategory: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/device_categories/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, DeviceCategory.from_dictionary)

        return decoded



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.transaction_metadata import TransactionMetadata


class TransactionsController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(TransactionsController, self).__init__(config, call_back)

    def transactions_get(self,
                         id=None,
                         consumer_id=None,
                         q=None,
                         order=None,
                         sort=None,
                         page=None,
                         per_page=None):
        """Does a GET request to /transactions.

        List Transactions

        Args:
            id (string, optional): Filter by ID + Examples     +
                `id=59b2ffaac8a589000100001b`     + use
                `id!=59b2ffaac8a589000100001b` to exclude by ID
            consumer_id (string, optional): ID of consumer
            q (string, optional): Filter by keyword
            order (string, optional): Filter by ascending or descending order
                + Examples     + asc     + desc
            sort (string, optional): Sort on the specified field
            page (float, optional): Number of pages to return
            per_page (float, optional): Number of records to return per page

        Returns:
            TransactionMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/transactions'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'id': id,
            'consumer_id': consumer_id,
            'q': q,
            'order': order,
            'sort': sort,
            'page': page,
            'per_page': per_page
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, TransactionMetadata.from_dictionary)

        return decoded

    def transactions_post(self,
                          body,
                          id=None,
                          consumer_id=None,
                          order=None,
                          sort=None,
                          page=None,
                          per_page=None,
                          q=None):
        """Does a POST request to /transactions.

        Create Transactions

        Args:
            body (TransactionRequest): TODO: type description here.
            id (string, optional): TODO: type description here.
            consumer_id (string, optional): TODO: type description here.
            order (string, optional): TODO: type description here.
            sort (string, optional): TODO: type description here.
            page (string, optional): TODO: type description here.
            per_page (string, optional): TODO: type description here.
            q (string, optional): TODO: type description here.

        Returns:
            TransactionMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/transactions'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'id': id,
            'consumer_id': consumer_id,
            'order': order,
            'sort': sort,
            'page': page,
            'per_page': per_page,
            'q': q
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, TransactionMetadata.from_dictionary)

        return decoded

    def transactions_by_id_get(self,
                               id):
        """Does a GET request to /transactions/{id}.

        View Transaction

        Args:
            id (string): ID of the subscription

        Returns:
            TransactionMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/transactions/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, TransactionMetadata.from_dictionary)

        return decoded

    def transactions_by_id_put(self,
                               id,
                               body):
        """Does a PUT request to /transactions/{id}.

        Update Transaction

        Args:
            id (string): ID of the subscription
            body (TransactionRequest): TODO: type description here.

        Returns:
            TransactionMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/transactions/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, TransactionMetadata.from_dictionary)

        return decoded

    def transactions_by_id_delete(self,
                                  id):
        """Does a DELETE request to /transactions/{id}.

        Delete Transaction

        Args:
            id (string): ID of the subscription

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/transactions/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.delete(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class PlaylistEntitlementMetadata(object):

    """Implementation of the 'PlaylistEntitlementMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        consumer_id (string): TODO: type description here.
        created_at (string): TODO: type description here.
        updated_at (string): TODO: type description here.
        video_title (string): TODO: type description here.
        expires_at (string): TODO: type description here.
        transaction_id (string): TODO: type description here.
        transaction_type (string): TODO: type description here.
        video_id (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "consumer_id": 'consumer_id',
        "created_at": 'created_at',
        "updated_at": 'updated_at',
        "video_title": 'video_title',
        "expires_at": 'expires_at',
        "transaction_id": 'transaction_id',
        "transaction_type": 'transaction_type',
        "video_id": 'video_id'
    }

    def __init__(self,
                 id=None,
                 consumer_id=None,
                 created_at=None,
                 updated_at=None,
                 video_title=None,
                 expires_at=None,
                 transaction_id=None,
                 transaction_type=None,
                 video_id=None):
        """Constructor for the PlaylistEntitlementMetadata class"""

        # Initialize members of the class
        self.id = id
        self.consumer_id = consumer_id
        self.created_at = created_at
        self.updated_at = updated_at
        self.video_title = video_title
        self.expires_at = expires_at
        self.transaction_id = transaction_id
        self.transaction_type = transaction_type
        self.video_id = video_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        consumer_id = dictionary.get('consumer_id')
        created_at = dictionary.get('created_at')
        updated_at = dictionary.get('updated_at')
        video_title = dictionary.get('video_title')
        expires_at = dictionary.get('expires_at')
        transaction_id = dictionary.get('transaction_id')
        transaction_type = dictionary.get('transaction_type')
        video_id = dictionary.get('video_id')

        # Return an object of this model
        return cls(id,
                   consumer_id,
                   created_at,
                   updated_at,
                   video_title,
                   expires_at,
                   transaction_id,
                   transaction_type,
                   video_id)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController


class PlayersController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(PlayersController, self).__init__(config, call_back)

    def embed_format_by_video_id_get(self,
                                     video_id,
                                     autoplay=None,
                                     audio=None,
                                     download=None,
                                     dvr=None):
        """Does a GET request to /embed/{video_id}.format.

        The full URL will look like
        https://player.zype.com/embed/[video_id].[format]. The format for the
        player response must be one of Iframes, JavaScript or JSON players 
        depending on device capabilities (Example: html, js, json)

        Args:
            video_id (string): ID of video
            autoplay (bool, optional): Whether or not to autoplay on page
                load
            audio (bool, optional): Request audio only
            download (bool, optional): Request download only player
            dvr (bool, optional): Enable DVR for Zype Live events

        Returns:
            object: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/embed/{video_id}.format'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'video_id': {'value': video_id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'autoplay': autoplay,
            'audio': audio,
            'download': download,
            'dvr': dvr
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = _response.text

        return decoded



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SortOption(object):

    """Implementation of the 'SortOption' model.

    TODO: type model description here.

    Attributes:
        sort_by_created_at (string): What value to sort the associated
            playlist by Must be one of: + created_at + published_at + title
        direction (string): Which direction to sort the associated playlist by
            Must be one of: + desc + asc
        sort_by_type (string): What datatype to sorty the associated playlist
            by Must be one of: + date + datetime + string + integer + array +
            boolean

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "sort_by_created_at": 'sort_by: created_at',
        "direction": 'direction',
        "sort_by_type": 'sort_by_type'
    }

    def __init__(self,
                 sort_by_created_at=None,
                 direction=None,
                 sort_by_type=None):
        """Constructor for the SortOption class"""

        # Initialize members of the class
        self.sort_by_created_at = sort_by_created_at
        self.direction = direction
        self.sort_by_type = sort_by_type

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        sort_by_created_at = dictionary.get('sort_by: created_at')
        direction = dictionary.get('direction')
        sort_by_type = dictionary.get('sort_by_type')

        # Return an object of this model
        return cls(sort_by_created_at,
                   direction,
                   sort_by_type)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class RevenueModelMetadata(object):

    """Implementation of the 'RevenueModelMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        created_at (string): TODO: type description here.
        image_content_type (string): TODO: type description here.
        image_file_name (string): TODO: type description here.
        image_file_size (string): TODO: type description here.
        image_fingerprint (string): TODO: type description here.
        image_updated_at (string): TODO: type description here.
        name (string): TODO: type description here.
        updated_at (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "created_at": 'created_at',
        "image_content_type": 'image_content_type',
        "image_file_name": 'image_file_name',
        "image_file_size": 'image_file_size',
        "image_fingerprint": 'image_fingerprint',
        "image_updated_at": 'image_updated_at',
        "name": 'name',
        "updated_at": 'updated_at'
    }

    def __init__(self,
                 id=None,
                 created_at=None,
                 image_content_type=None,
                 image_file_name=None,
                 image_file_size=None,
                 image_fingerprint=None,
                 image_updated_at=None,
                 name=None,
                 updated_at=None):
        """Constructor for the RevenueModelMetadata class"""

        # Initialize members of the class
        self.id = id
        self.created_at = created_at
        self.image_content_type = image_content_type
        self.image_file_name = image_file_name
        self.image_file_size = image_file_size
        self.image_fingerprint = image_fingerprint
        self.image_updated_at = image_updated_at
        self.name = name
        self.updated_at = updated_at

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        created_at = dictionary.get('created_at')
        image_content_type = dictionary.get('image_content_type')
        image_file_name = dictionary.get('image_file_name')
        image_file_size = dictionary.get('image_file_size')
        image_fingerprint = dictionary.get('image_fingerprint')
        image_updated_at = dictionary.get('image_updated_at')
        name = dictionary.get('name')
        updated_at = dictionary.get('updated_at')

        # Return an object of this model
        return cls(id,
                   created_at,
                   image_content_type,
                   image_file_name,
                   image_file_size,
                   image_fingerprint,
                   image_updated_at,
                   name,
                   updated_at)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class File24(object):

    """Implementation of the 'File24' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        height (float): TODO: type description here.
        width (float): TODO: type description here.
        quality (string): TODO: type description here.
        url (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "height": 'height',
        "width": 'width',
        "quality": 'quality',
        "url": 'url'
    }

    def __init__(self,
                 id=None,
                 height=None,
                 width=None,
                 quality=None,
                 url=None):
        """Constructor for the File24 class"""

        # Initialize members of the class
        self.id = id
        self.height = height
        self.width = width
        self.quality = quality
        self.url = url

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        height = dictionary.get('height')
        width = dictionary.get('width')
        quality = dictionary.get('quality')
        url = dictionary.get('url')

        # Return an object of this model
        return cls(id,
                   height,
                   width,
                   quality,
                   url)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.segment_metadata import SegmentMetadata


class SegmentsController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(SegmentsController, self).__init__(config, call_back)

    def videos_segments_by_video_id_get(self,
                                        video_id):
        """Does a GET request to /videos/{video_id}/segments.

        List Segments

        Args:
            video_id (string): ID of video

        Returns:
            list of SegmentMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{video_id}/segments'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'video_id': {'value': video_id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, SegmentMetadata.from_dictionary)

        return decoded

    def videos_segments_by_video_id_post(self,
                                         body,
                                         video_id):
        """Does a POST request to /videos/{video_id}/segments.

        Create Segment

        Args:
            body (Segment): TODO: type description here.
            video_id (string): TODO: type description here.

        Returns:
            SegmentMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{video_id}/segments'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'video_id': {'value': video_id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, SegmentMetadata.from_dictionary)

        return decoded

    def videos_segments_by_video_id_and_id_get(self,
                                               video_id,
                                               id):
        """Does a GET request to /videos/{video_id}/segments/{id}.

        View Segment

        Args:
            video_id (string): ID of video
            id (string): ID of segment

        Returns:
            SegmentMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{video_id}/segments/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'video_id': {'value': video_id, 'encode': True},
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, SegmentMetadata.from_dictionary)

        return decoded

    def videos_segments_by_video_id_and_id_put(self,
                                               video_id,
                                               id,
                                               body):
        """Does a PUT request to /videos/{video_id}/segments/{id}.

        Update Segment

        Args:
            video_id (string): ID of video
            id (string): ID of segment
            body (Segment): TODO: type description here.

        Returns:
            SegmentMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{video_id}/segments/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'video_id': {'value': video_id, 'encode': True},
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, SegmentMetadata.from_dictionary)

        return decoded

    def videos_segments_by_video_id_and_id_delete(self,
                                                  video_id,
                                                  id):
        """Does a DELETE request to /videos/{video_id}/segments/{id}.

        Delete Segment

        Args:
            video_id (string): ID of video
            id (string): ID of segment

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{video_id}/segments/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'video_id': {'value': video_id, 'encode': True},
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.delete(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class OAuthRequest(object):

    """Implementation of the 'OAuthRequest' model.

    TODO: type model description here.

    Attributes:
        client_id (string): The client ID for your Zype application
        client_secret (string): The client secret for your Zype application
        username (string): The username (email) of the consumer
        password (string): Password of the consumer. Password is required if
            username is used to authenticate.
        linked_device_id (string): The linked device ID of the consumer.
            Required if using username to authenticate.
        pin (string): The pin for the linked device. Pin is required if linked
            device ID is used to authenticate.
        grant_type (string): Use ‘password’. Required if using linked device
            ID to authenticate.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": 'client_id',
        "client_secret": 'client_secret',
        "username": 'username',
        "password": 'password',
        "linked_device_id": 'linked_device_id',
        "pin": 'pin',
        "grant_type": 'grant_type'
    }

    def __init__(self,
                 client_id=None,
                 client_secret=None,
                 username=None,
                 password=None,
                 linked_device_id=None,
                 pin=None,
                 grant_type=None):
        """Constructor for the OAuthRequest class"""

        # Initialize members of the class
        self.client_id = client_id
        self.client_secret = client_secret
        self.username = username
        self.password = password
        self.linked_device_id = linked_device_id
        self.pin = pin
        self.grant_type = grant_type

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id = dictionary.get('client_id')
        client_secret = dictionary.get('client_secret')
        username = dictionary.get('username')
        password = dictionary.get('password')
        linked_device_id = dictionary.get('linked_device_id')
        pin = dictionary.get('pin')
        grant_type = dictionary.get('grant_type')

        # Return an object of this model
        return cls(client_id,
                   client_secret,
                   username,
                   password,
                   linked_device_id,
                   pin,
                   grant_type)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.video_entitlement_metadata import VideoEntitlementMetadata
from zypev1.models.check_entitlement_response import CheckEntitlementResponse


class VideoEntitlementsController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(VideoEntitlementsController, self).__init__(config, call_back)

    def consumer_videos_get(self,
                            id=None,
                            created_at=None,
                            expires_at=None,
                            transaction_id=None,
                            transaction_type=None,
                            video_id=None,
                            q=None,
                            order=None,
                            sort=None,
                            page=None,
                            per_page=None):
        """Does a GET request to /consumer/videos.

        List All Video Entitlements

        Args:
            id (string, optional): Filter by ID + Examples     +
                `id=5992f328ce593000ef000008`     + use
                `id!=5992f328ce593000ef000008` to exclude by id
            created_at (date, optional): Filter by created at date using times
                in ISO8601 format Note: Range filters can be applied by adding
                a suffix: ‘.gt’, ‘.gte’, ‘.lt’, ‘lte’ (Example:
                expires_at.gte) + Examples     + `2017-01-01T00:00:00-00:00` -
                in ISO8601 format     + `1483228800` - Unix timestamps
            expires_at (date, optional): Range filters can be applied by
                adding a suffix: ‘.gt’, ‘.gte’, ‘.lt’, ‘lte’ (Example:
                created_at.gte) + Examples     + `2017-01-01T00:00:00-00:00` -
                in ISO8601 format     + `1483228800` - Unix timestamps
            transaction_id (string, optional): Filter by transaction
            transaction_type (string, optional): + Examples     + purchase    
                + subscription     + rental
            video_id (string, optional): Filter by video
            q (string, optional): Filter by keyword
            order (string, optional): Filter by ascending or descending order
                + Examples     + asc     + desc
            sort (string, optional): Sort on the specified field
            page (float, optional): Number of pages to return
            per_page (float, optional): Number of records to return per page

        Returns:
            list of VideoEntitlementMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/consumer/videos'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'id': id,
            'created_at': created_at,
            'expires_at': expires_at,
            'transaction_id': transaction_id,
            'transaction_type': transaction_type,
            'video_id': video_id,
            'q': q,
            'order': order,
            'sort': sort,
            'page': page,
            'per_page': per_page
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoEntitlementMetadata.from_dictionary)

        return decoded

    def consumers_videos_by_consumer_id_get(self,
                                            consumer_id):
        """Does a GET request to /consumers/{consumer_id}/videos.

        List Video Entitlements

        Args:
            consumer_id (string): ID of the consumer whose video entitlements
                will be retrieved

        Returns:
            VideoEntitlementMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/consumers/{consumer_id}/videos'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'consumer_id': {'value': consumer_id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoEntitlementMetadata.from_dictionary)

        return decoded

    def consumers_videos_by_consumer_id_post(self,
                                             body,
                                             consumer_id):
        """Does a POST request to /consumers/{consumer_id}/videos.

        Create Video Entitlement

        Args:
            body (VideoEntitlementRequest): TODO: type description here.
            consumer_id (string): TODO: type description here.

        Returns:
            VideoEntitlementMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/consumers/{consumer_id}/videos'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'consumer_id': {'value': consumer_id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoEntitlementMetadata.from_dictionary)

        return decoded

    def consumers_videos_by_consumer_id_and_id_get(self,
                                                   consumer_id,
                                                   id):
        """Does a GET request to /consumers/{consumer_id}/videos/{id}.

        View Video Entitlement

        Args:
            consumer_id (string): ID of the consumer whose video entitlements
                will be retrieved
            id (string): ID of the video entitlement

        Returns:
            VideoEntitlementMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/consumers/{consumer_id}/videos/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'consumer_id': {'value': consumer_id, 'encode': True},
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoEntitlementMetadata.from_dictionary)

        return decoded

    def consumers_videos_by_consumer_id_and_id_put(self,
                                                   consumer_id,
                                                   id,
                                                   body):
        """Does a PUT request to /consumers/{consumer_id}/videos/{id}.

        Update Video Entitlement

        Args:
            consumer_id (string): ID of the consumer whose video entitlements
                will be retrieved
            id (string): ID of the video entitlement
            body (VideoEntitlementRequest): TODO: type description here.

        Returns:
            VideoEntitlementMetadata: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/consumers/{consumer_id}/videos/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'consumer_id': {'value': consumer_id, 'encode': True},
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json',
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.config.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(body))
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, VideoEntitlementMetadata.from_dictionary)

        return decoded

    def consumers_videos_by_consumer_id_and_id_delete(self,
                                                      consumer_id,
                                                      id):
        """Does a DELETE request to /consumers/{consumer_id}/videos/{id}.

        Delete a Video Entitlement

        Args:
            consumer_id (string): ID of the consumer whose video entitlements
                will be retrieved
            id (string): ID of the video entitlement

        Returns:
            void: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/consumers/{consumer_id}/videos/{id}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'consumer_id': {'value': consumer_id, 'encode': True},
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.config.http_client.delete(_query_url)
        _response = self.execute_request(_request)
        self.validate_response(_response)

    def videos_entitled_by_id_get(self,
                                  id,
                                  access_token):
        """Does a GET request to /videos/{id}/entitled.

        Check Entitlement

        Args:
            id (string): ID of the video entitlement
            access_token (string): OAuth token of a consumer

        Returns:
            CheckEntitlementResponse: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/videos/{id}/entitled'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, {
            'id': {'value': id, 'encode': True}
        })
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'access_token': access_token
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, CheckEntitlementResponse.from_dictionary)

        return decoded



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class SegmentMetadata(object):

    """Implementation of the 'SegmentMetadata' model.

    TODO: type model description here.

    Attributes:
        id (string): ID of the record
        video_id (string): TODO: type description here.
        start (float): When the segment starts
        end (float): When the segment ends
        description (string): Description of segment

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "video_id": 'video_id',
        "start": 'start',
        "end": 'end',
        "description": 'description'
    }

    def __init__(self,
                 id=None,
                 video_id=None,
                 start=None,
                 end=None,
                 description=None):
        """Constructor for the SegmentMetadata class"""

        # Initialize members of the class
        self.id = id
        self.video_id = video_id
        self.start = start
        self.end = end
        self.description = description

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        video_id = dictionary.get('video_id')
        start = dictionary.get('start')
        end = dictionary.get('end')
        description = dictionary.get('description')

        # Return an object of this model
        return cls(id,
                   video_id,
                   start,
                   end,
                   description)



__all__ = [
    'ad_tag',
    'ad_tag_metadata',
    'ad_tag_request',
    'ad_tag_3',
    'app',
    'category',
    'category_value',
    'category_values',
    'category_metadata',
    'category_request',
    'consumer',
    'consumer_metadata',
    'consumer_request',
    'content_rule',
    'geography',
    'content_rule_metadata',
    'content_rule_request',
    'content_rule_19',
    'device',
    'device_category',
    'device_pin',
    'embedded_category',
    'file_24',
    'image',
    'o_auth',
    'o_auth_request',
    'o_auth_refresh_request',
    'o_auth_status',
    'application',
    'plan_metadata',
    'playlist',
    'sort_option',
    'playlist_entitlement',
    'playlist_entitlement_metadata',
    'playlist_entitlement_request',
    'entitlement',
    'playlist_metadata',
    'thumbnail',
    'playlist_request',
    'redemption_code',
    'redemption_code_metadata',
    'redemption_code_request',
    'redemption_code_45',
    'revenue_model_metadata',
    'segment',
    'segment_metadata',
    'segment_request',
    'subscription_metadata',
    'subscription_request',
    'transaction_metadata',
    'transaction_request',
    'video',
    'video_entitlement',
    'video_entitlement_metadata',
    'video_entitlement_request',
    'video_favorite_metadata',
    'video_favorite_request',
    'video_manifest',
    'video_metadata',
    'zobject',
    'video_import',
    'video_request',
    'video_source',
    'video_source_metadata',
    'video_source_request',
    'video_source_71',
    'video_zobject',
    'zobject_metadata',
    'picture_metadata',
    'styles',
    'original',
    'zobject_request',
    'picture',
    'zobject_attribute',
    'zobject_attribute_metadata',
    'zobject_type',
    'zobject_type_metadata',
    'zobject_attributes',
    'zobject_type_request',
    'zobject_type_86',
    'zobject_attributes_attributes',
    'add_zobject_s_to_video_request',
    'add_a_video_to_a_playlist_request',
    'view_relationsips_response',
    'attaching_a_video_to_a_video_import_request',
    'check_entitlement_response',
]



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

from zypev1.api_helper import APIHelper
from zypev1.configuration import Server
from zypev1.controllers.base_controller import BaseController
from zypev1.models.app import App


class AppsController(BaseController):

    """A Controller to access Endpoints in the zypev1 API."""

    def __init__(self, config, call_back=None):
        super(AppsController, self).__init__(config, call_back)

    def app_get(self,
                app_key):
        """Does a GET request to /app.

        View App

        Args:
            app_key (string): App key provided by Zype

        Returns:
            App: Response from the API.

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/app'
        _query_builder = self.config.get_base_uri()
        _query_builder += _url_path
        _query_parameters = {
            'app_key': app_key
        }
        _query_builder = APIHelper.append_url_with_query_parameters(
            _query_builder,
            _query_parameters
        )
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'accept': 'application/json'
        }

        # Prepare and execute request
        _request = self.config.http_client.get(_query_url, headers=_headers)
        _response = self.execute_request(_request)
        self.validate_response(_response)

        decoded = APIHelper.json_deserialize(_response.text, App.from_dictionary)

        return decoded



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import json
import dateutil.parser

from tests.controllers.controller_test_base import ControllerTestBase
from tests.test_helper import TestHelper
from tests.http_response_catcher import HttpResponseCatcher
from zypev1.api_helper import APIHelper
from zypev1.controllers.transactions_controller import TransactionsController


class TransactionsControllerTests(ControllerTestBase):

    @classmethod
    def setUpClass(cls):
        super(TransactionsControllerTests, cls).setUpClass()
        cls.response_catcher = HttpResponseCatcher()
        cls.controller = TransactionsController(cls.config, cls.response_catcher)

    # Testcase for testing endpoint Delete Transaction
    def test_delete_transaction_1(self):
        # Parameters for the API call
        id = '5a09c873f716e4000100003e'

        # Perform the API call through the SDK function
        self.controller.transactions_by_id_delete(id)

        # Test response code
        self.assertEquals(self.response_catcher.response.status_code, 204)

        # Test headers
        expected_headers = {}
        expected_headers['content-type'] = None

        self.assertTrue(TestHelper.match_headers(expected_headers, self.response_catcher.response.headers))





# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""
from zypev1.models.application import Application


class OAuthStatus(object):

    """Implementation of the 'OAuthStatus' model.

    TODO: type model description here.

    Attributes:
        resource_owner_id (string): TODO: type description here.
        scopes (list of string): TODO: type description here.
        expires_in_seconds (float): TODO: type description here.
        application (Application): TODO: type description here.
        created_at (float): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "resource_owner_id": 'resource_owner_id',
        "scopes": 'scopes',
        "expires_in_seconds": 'expires_in_seconds',
        "application": 'application',
        "created_at": 'created_at'
    }

    def __init__(self,
                 resource_owner_id=None,
                 scopes=None,
                 expires_in_seconds=None,
                 application=None,
                 created_at=None):
        """Constructor for the OAuthStatus class"""

        # Initialize members of the class
        self.resource_owner_id = resource_owner_id
        self.scopes = scopes
        self.expires_in_seconds = expires_in_seconds
        self.application = application
        self.created_at = created_at

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        resource_owner_id = dictionary.get('resource_owner_id')
        scopes = dictionary.get('scopes')
        expires_in_seconds = dictionary.get('expires_in_seconds')
        application = Application.from_dictionary(dictionary.get('application')) if dictionary.get('application') else None
        created_at = dictionary.get('created_at')

        # Return an object of this model
        return cls(resource_owner_id,
                   scopes,
                   expires_in_seconds,
                   application,
                   created_at)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Geography(object):

    """Implementation of the 'Geography' model.

    TODO: type model description here.

    Attributes:
        id (string): TODO: type description here.
        countries (object): List of countries supplied by you

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "countries": 'countries'
    }

    def __init__(self,
                 id=None,
                 countries=None):
        """Constructor for the Geography class"""

        # Initialize members of the class
        self.id = id
        self.countries = countries

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        countries = dictionary.get('countries')

        # Return an object of this model
        return cls(id,
                   countries)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class VideoSource(object):

    """Implementation of the 'VideoSource' model.

    TODO: type model description here.

    Attributes:
        name (string): TODO: type description here.
        guid (string): Globally unique identifier given by the video source
        affiliate_code (string): You can update this field for the following
            video source types: - Crunchyroll
        partner_name (string): You can update this field for the following
            video source types: - Hulu
        category_id (string): You can update this field for the following
            video source types: - MRSS
        auto_activate (bool): You can update this field for the following
            video source types: - MRSS
        auto_add (bool): You can update this field for the following video
            source types: - MRSS
        auto_deactivate (bool): You can update this field for the following
            video source types: - MRSS
        sync_interval (string): Options are: + daily + hourly
        sync_video_data_source (bool): TODO: type description here.
        url (string): URL of the MRSS feed. You can update this field for the
            following video source types: - MRSS
        import_from (string): Starting date of a date range to import from
        import_to (string): Ending date of a date range to import to
        editable (bool): TODO: type description here.
        video_count (string): How many videos are part of this video source

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name": 'name',
        "guid": 'guid',
        "affiliate_code": 'affiliate_code',
        "partner_name": 'partner_name',
        "category_id": 'category_id',
        "auto_activate": 'auto_activate',
        "auto_add": 'auto_add',
        "auto_deactivate": 'auto_deactivate',
        "sync_interval": 'sync_interval',
        "sync_video_data_source": 'sync_video_data_source',
        "url": 'url',
        "import_from": 'import_from',
        "import_to": 'import_to',
        "editable": 'editable',
        "video_count": 'video_count'
    }

    def __init__(self,
                 name=None,
                 guid=None,
                 affiliate_code=None,
                 partner_name=None,
                 category_id=None,
                 auto_activate=None,
                 auto_add=None,
                 auto_deactivate=None,
                 sync_interval=None,
                 sync_video_data_source=None,
                 url=None,
                 import_from=None,
                 import_to=None,
                 editable=None,
                 video_count=None):
        """Constructor for the VideoSource class"""

        # Initialize members of the class
        self.name = name
        self.guid = guid
        self.affiliate_code = affiliate_code
        self.partner_name = partner_name
        self.category_id = category_id
        self.auto_activate = auto_activate
        self.auto_add = auto_add
        self.auto_deactivate = auto_deactivate
        self.sync_interval = sync_interval
        self.sync_video_data_source = sync_video_data_source
        self.url = url
        self.import_from = import_from
        self.import_to = import_to
        self.editable = editable
        self.video_count = video_count

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        guid = dictionary.get('guid')
        affiliate_code = dictionary.get('affiliate_code')
        partner_name = dictionary.get('partner_name')
        category_id = dictionary.get('category_id')
        auto_activate = dictionary.get('auto_activate')
        auto_add = dictionary.get('auto_add')
        auto_deactivate = dictionary.get('auto_deactivate')
        sync_interval = dictionary.get('sync_interval')
        sync_video_data_source = dictionary.get('sync_video_data_source')
        url = dictionary.get('url')
        import_from = dictionary.get('import_from')
        import_to = dictionary.get('import_to')
        editable = dictionary.get('editable')
        video_count = dictionary.get('video_count')

        # Return an object of this model
        return cls(name,
                   guid,
                   affiliate_code,
                   partner_name,
                   category_id,
                   auto_activate,
                   auto_add,
                   auto_deactivate,
                   sync_interval,
                   sync_video_data_source,
                   url,
                   import_from,
                   import_to,
                   editable,
                   video_count)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class TransactionRequest(object):

    """Implementation of the 'TransactionRequest' model.

    TODO: type model description here.

    Attributes:
        consumer_id (string): TODO: type description here.
        video_id (string): TODO: type description here.
        playlist_id (string): TODO: type description here.
        pass_plan_id (string): TODO: type description here.
        currency (string): TODO: type description here.
        description (string): TODO: type description here.
        transaction_type (string): Must be one of:     + purchase     + rental
            + pass
        payment_nonce_tok_1_azt_ek_chy_l_vk_xdp_8_s_wnuw_ae_w (string): TODO:
            type description here.
        roku_id (string): TODO: type description here.
        apple_id (string): TODO: type description here.
        third_party_id (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "consumer_id": 'consumer_id',
        "video_id": 'video_id',
        "playlist_id": 'playlist_id',
        "pass_plan_id": 'pass_plan_id',
        "currency": 'currency',
        "description": 'description',
        "transaction_type": 'transaction_type',
        "payment_nonce_tok_1_azt_ek_chy_l_vk_xdp_8_s_wnuw_ae_w": 'payment_nonce: tok_1AztEkChyLVkXdp8SWnuwAeW',
        "roku_id": 'roku_id',
        "apple_id": 'apple_id',
        "third_party_id": 'third_party_id'
    }

    def __init__(self,
                 consumer_id=None,
                 video_id=None,
                 playlist_id=None,
                 pass_plan_id=None,
                 currency=None,
                 description=None,
                 transaction_type=None,
                 payment_nonce_tok_1_azt_ek_chy_l_vk_xdp_8_s_wnuw_ae_w=None,
                 roku_id=None,
                 apple_id=None,
                 third_party_id=None):
        """Constructor for the TransactionRequest class"""

        # Initialize members of the class
        self.consumer_id = consumer_id
        self.video_id = video_id
        self.playlist_id = playlist_id
        self.pass_plan_id = pass_plan_id
        self.currency = currency
        self.description = description
        self.transaction_type = transaction_type
        self.payment_nonce_tok_1_azt_ek_chy_l_vk_xdp_8_s_wnuw_ae_w = payment_nonce_tok_1_azt_ek_chy_l_vk_xdp_8_s_wnuw_ae_w
        self.roku_id = roku_id
        self.apple_id = apple_id
        self.third_party_id = third_party_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        consumer_id = dictionary.get('consumer_id')
        video_id = dictionary.get('video_id')
        playlist_id = dictionary.get('playlist_id')
        pass_plan_id = dictionary.get('pass_plan_id')
        currency = dictionary.get('currency')
        description = dictionary.get('description')
        transaction_type = dictionary.get('transaction_type')
        payment_nonce_tok_1_azt_ek_chy_l_vk_xdp_8_s_wnuw_ae_w = dictionary.get('payment_nonce: tok_1AztEkChyLVkXdp8SWnuwAeW')
        roku_id = dictionary.get('roku_id')
        apple_id = dictionary.get('apple_id')
        third_party_id = dictionary.get('third_party_id')

        # Return an object of this model
        return cls(consumer_id,
                   video_id,
                   playlist_id,
                   pass_plan_id,
                   currency,
                   description,
                   transaction_type,
                   payment_nonce_tok_1_azt_ek_chy_l_vk_xdp_8_s_wnuw_ae_w,
                   roku_id,
                   apple_id,
                   third_party_id)



# -*- coding: utf-8 -*-

"""
zypev1

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""


class Device(object):

    """Implementation of the 'Device' model.

    TODO: type model description here.

    Attributes:
        id (string): ID of the device
        description (string): TODO: type description here.
        name (string): TODO: type description here.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": '_id',
        "description": 'description',
        "name": 'name'
    }

    def __init__(self,
                 id=None,
                 description=None,
                 name=None):
        """Constructor for the Device class"""

        # Initialize members of the class
        self.id = id
        self.description = description
        self.name = name

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        id = dictionary.get('_id')
        description = dictionary.get('description')
        name = dictionary.get('name')

        # Return an object of this model
        return cls(id,
                   description,
                   name)
